@@ -112,6 +112,25 @@ static void verb_GameUndo_cb (BonoboUIComponent * uic, gpointer user_data,
 static void verb_GameScores_cb (BonoboUIComponent * uic, gpointer user_data,
 				const char *cname)
 {
+  struct stat scores_file;
+
+  stat (SCORESDIR "/atomix.scores", &scores_file);
+
+  if (scores_file.st_size == 0)
+    {
+      GtkWidget *dlg = gtk_message_dialog_new (GTK_WINDOW (app->mainwin),
+					       GTK_DIALOG_MODAL,
+					       GTK_MESSAGE_INFO,
+					       GTK_BUTTONS_CLOSE,
+					       _("You have not achieved any "
+						 "scores yet. Play a little "
+						 "before coming back!"));
+      gtk_dialog_run (GTK_DIALOG (dlg));
+      gtk_widget_destroy (GTK_WIDGET (dlg));
+
+      return;
+    }
+
   gnome_scores_display ("Atomix", PACKAGE, NULL, 0);
 }
 
@@ -521,7 +540,7 @@ static void update_statistics (AtomixApp *app)
 
       /* set levelname */
       gtk_label_set_text (GTK_LABEL (app->lb_name),
-			  level_get_name (app->level));
+			  _(level_get_name (app->level)));
 
       /* set score */
       g_snprintf (str_buffer, 10, "%i", app->score);
@@ -747,6 +766,14 @@ static AtomixApp *create_gui (GnomeProgram *prog)
 
   /* create window contents */
   content = create_mainwin_content (app);
+
+  gtk_window_set_icon_from_file (GTK_WINDOW (app->mainwin),
+				 g_build_filename (DATADIR,
+						   "pixmaps",
+						   "atomix-icon.png",
+						   NULL),
+				 NULL);
+
   gtk_widget_show (GTK_WIDGET (content));
 
   bonobo_window_set_contents (BONOBO_WINDOW (app->mainwin), content);
